Stan Math Library: stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Attributes | List of all members
stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT > Struct Template Reference

`#include <autodiffstackstorage.hpp>`

## Static Public Attributes
static std::vector< ChainableT * > | var_stack_
static std::vector< ChainableT * > | var_nochain_stack_
static std::vector< ChainableAllocT * > | var_alloc_stack_
static stack_alloc | memalloc_
static std::vector< size_t > | nested_var_stack_sizes_
static std::vector< size_t > | nested_var_nochain_stack_sizes_
static std::vector< size_t > | nested_var_alloc_stack_starts_

## Detailed Description

### template<typename ChainableT, typename ChainableAllocT>
struct stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT >

Definition at line 12 of file autodiffstackstorage.hpp.

## Member Data Documentation

template<typename ChainableT , typename ChainableAllocT >

stack_alloc stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT >::memalloc_
| static

Definition at line 16 of file autodiffstackstorage.hpp.

template<typename ChainableT , typename ChainableAllocT >

std::vector< size_t > stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT >::nested_var_alloc_stack_starts_
| static

Definition at line 21 of file autodiffstackstorage.hpp.

template<typename ChainableT , typename ChainableAllocT >

std::vector< size_t > stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT >::nested_var_nochain_stack_sizes_
| static

Definition at line 20 of file autodiffstackstorage.hpp.

template<typename ChainableT , typename ChainableAllocT >

std::vector< size_t > stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT >::nested_var_stack_sizes_
| static

Definition at line 19 of file autodiffstackstorage.hpp.

template<typename ChainableT , typename ChainableAllocT >

std::vector< ChainableAllocT * > stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT >::var_alloc_stack_
| static

Definition at line 15 of file autodiffstackstorage.hpp.

template<typename ChainableT , typename ChainableAllocT >

std::vector< ChainableT * > stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT >::var_nochain_stack_
| static

Definition at line 14 of file autodiffstackstorage.hpp.

template<typename ChainableT , typename ChainableAllocT >

std::vector< ChainableT * > stan::math::AutodiffStackStorage< ChainableT, ChainableAllocT >::var_stack_
| static

Definition at line 13 of file autodiffstackstorage.hpp.

The documentation for this struct was generated from the following file:

- stan/math/rev/core/autodiffstackstorage.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.